@@ -19,6 +19,8 @@ then use `tweet` directive and `tw` role.
 
    :tw:`@shomah4a`
 
+   .. timeline:: 319830355039371264
+
 
 finally, build your sphinx project.
 
@@ -28,7 +30,7 @@ finally, build your sphinx project.
    $ make html
 '''
 
-__version__ = '0.2.1'
+__version__ = '0.3.0'
 __author__ = '@shomah4a'
 __license__ = 'LGPLv3'
 
@@ -36,7 +38,7 @@ __license__ = 'LGPLv3'
 
 def setup(app):
 
-    from . import tweet, user
+    from . import tweet, user, timeline
 
     app.add_javascript('http://platform.twitter.com/widgets.js')
 
@@ -44,6 +46,10 @@ def setup(app):
                  html=(tweet.visit, tweet.depart))
     app.add_directive('tweet', tweet.TweetDirective)
 
+    app.add_node(timeline.timeline,
+                 html=(timeline.visit, timeline.depart))
+    app.add_directive('timeline', timeline.TimelineDirective)
+
     app.add_node(user.twnode,
                  html=(user.visit, user.depart))
     app.add_role('tw', user.tw_role)
